@@ -1,9 +1,9 @@
-import abc
+from abc import ABC, abstractmethod
 
 from python_dice.interface.constraint.i_constraint_set import IConstraintSet
 
 
-class IConstraintSetFactory(abc.ABC):
-    @abc.abstractmethod
+class IConstraintSetFactory(ABC):
+    @abstractmethod
     def create_constraint_set(self) -> IConstraintSet:
         pass
