@@ -1,11 +1,11 @@
-import abc
+from abc import ABC, abstractmethod
 
 from python_dice.interface.probability_distribution.i_probability_distribution_state import (
     IProbabilityDistributionState,
 )
 
 
-class IProbabilityDistributionStateFactory(abc.ABC):
-    @abc.abstractmethod
+class IProbabilityDistributionStateFactory(ABC):
+    @abstractmethod
     def create_new_empty_set(self) -> IProbabilityDistributionState:
         pass
