@@ -1,4 +1,4 @@
-import typing
+from typing import Optional
 
 from python_dice.interface.constraint.i_constraint_set_factory import IConstraintSetFactory
 from python_dice.interface.probability_distribution.i_probability_outcome import IProbabilityOutcome
@@ -8,7 +8,7 @@ from python_dice.src.probability_distribution.probability_outcome import Probabi
 
 
 class ProbabilityOutcomeFactory(IProbabilityOutcomeFactory):
-    def __init__(self, constraint_set_factory: typing.Optional[IConstraintSetFactory] = None):
+    def __init__(self, constraint_set_factory: Optional[IConstraintSetFactory] = None):
         if constraint_set_factory is None:
             constraint_set_factory = ConstraintSetFactory()
         self._constraint_set_factory = constraint_set_factory
